@@ -211,7 +211,7 @@ class IrcBot(object):
         self.use_sasl = use_sasl
         self.use_ssl = use_ssl
         self.tables = tables
-        self.delay=False
+        self.delay=delay
 
         self.send_message_channel, self.receive_message_channel = trio.open_memory_channel(
             0)
